package com.jpsoft.picc.scheduled;


import com.jpsoft.picc.modules.base.entity.InsuranceDefinition;
import com.jpsoft.picc.modules.base.service.InsuranceDefinitionService;
import com.jpsoft.picc.modules.business.entity.InsuranceApplication;
import com.jpsoft.picc.modules.business.entity.InsurancePolicy;
import com.jpsoft.picc.modules.business.entity.InsurancePolicyMember;
import com.jpsoft.picc.modules.business.service.InsurancePolicyMemberService;
import com.jpsoft.picc.modules.business.service.InsurancePolicyService;
import com.jpsoft.picc.modules.common.constant.PolicyStatus;
import lombok.extern.apachecommons.CommonsLog;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.joda.time.DateTime;
import org.joda.time.Days;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.util.Calendar;
import java.util.Date;
import java.util.List;

@Component
@Configuration
@Slf4j
public class FissionWantedTask {
    @Autowired
    private InsurancePolicyService insurancePolicyService;

    @Autowired
    private InsurancePolicyMemberService insurancePolicyMemberService;

    @Autowired
    private InsuranceDefinitionService insuranceDefinitionService;

    //每5分钟执行一次
    @Scheduled(cron="0 0/5 * * * ?")
    public void staticCronTask() {
        editInsurancePolicy();
    }

    private void editInsurancePolicy(){
        //获取待调整下月投保单
        List<InsurancePolicy> insurancePolicyList = insurancePolicyService.toBeAdjustedPolicy(PolicyStatus.Draft.getValue() + "");

        int affectCount = 0;

        for (InsurancePolicy insurancePolicy :insurancePolicyList) {
            String id = insurancePolicy.getId();

            InsuranceDefinition insuranceDefinition = insuranceDefinitionService.get(insurancePolicy.getDefinitionId());

            if (StringUtils.isEmpty(insuranceDefinition.getCutOffTime())) {
                continue;
            }

            Integer limit = Integer.valueOf(insuranceDefinition.getCutOffTime());

            DateTime startTime = new DateTime(insurancePolicy.getStartTime());

            int days = Days.daysBetween(DateTime.now(),startTime).getDays();

            if (days>limit){
                continue;
            }

            List<InsurancePolicyMember> insurancePolicyMemberList = insurancePolicyMemberService.findByPolicyId(id);

            boolean isUnChecked = false;

            for (InsurancePolicyMember insurancePolicyMember:insurancePolicyMemberList) {
                String memberStatus = insurancePolicyMember.getStatus();
                //花名册人员是否为已复核状态
                if(!("2").equals(memberStatus)){
                    isUnChecked = true;
                    break;
                }
            }

            if(isUnChecked){
                insurancePolicy.setStatus(PolicyStatus.PendingTrial.getValue() + "");
            }
            else{
                insurancePolicy.setStatus(PolicyStatus.PendingMakePolicy.getValue() + "");
            }

            insurancePolicyService.update(insurancePolicy);
            affectCount++;
        }

        log.warn("已自动修改状态:" + affectCount + "条记录");
    }
}
