package com.jpsoft.picc.modules.business.entity;

import java.util.Date;
import java.math.BigDecimal;

import com.jpsoft.picc.modules.common.constant.PolicyStatus;
import lombok.Data;
import org.apache.commons.lang3.StringUtils;
import org.springframework.format.annotation.DateTimeFormat;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
  描述:business_insurance_application的实体类
 */
@Data
@ApiModel(value = "business_insurance_application的实体类")
public class InsuranceApplication {
    @ApiModelProperty(value = "ID")
	private String id;
    @ApiModelProperty(value = "企业ID")
	private String companyId;
	@ApiModelProperty(value = "险种名称")
	private String definitionName;
    @ApiModelProperty(value = "保险种类")
	private String definitionId;
    @ApiModelProperty(value = "投保人姓名")
	private String insuredName;
    @ApiModelProperty(value = "联系电话")
	private String insuredTel;
    @ApiModelProperty(value = "企业名称")
	private String companyName;
    @ApiModelProperty(value = "组织机构代码证")
	private String usccCode;
    @ApiModelProperty(value = "营业范围")
	private String businessScope;
	@ApiModelProperty(value = "营业性质")
	private String businessNature;
	@ApiModelProperty(value = "营业性质描述")
	private String businessNatureN;
	@ApiModelProperty(value = "行业类型")
	private String industryType;
    @ApiModelProperty(value = "联系电话")
	private String tel;
    @ApiModelProperty(value = "邮编")
	private String postal;
    @ApiModelProperty(value = "雇员人数")
	private Integer employeesNumber;
    @ApiModelProperty(value = "已投保人数")
	private Integer insuredNumber;
    @ApiModelProperty(value = "公司地址")
	private String companyAddress;
    @ApiModelProperty(value = "近三年损失情况")
	private String lossInRecentYears;

	@DateTimeFormat(pattern="yyyy-MM-dd")
	@JsonFormat(pattern = "yyyy-MM-dd",timezone ="GMT+8")
    @ApiModelProperty(value = "保障开始时间")
	private Date startTime;

	@DateTimeFormat(pattern="yyyy-MM-dd")
	@JsonFormat(pattern = "yyyy-MM-dd",timezone ="GMT+8")
    @ApiModelProperty(value = "保障结束时间")
	private Date endTime;

    @ApiModelProperty(value = "保险费合计(总金额)")
	private BigDecimal insuranceFee;
    @ApiModelProperty(value = "状态:草稿10/待初审20/待复审30/待缴费40/待制单50/待出单60/已出单70/已过期100")
	private String status;
	@ApiModelProperty(value = "状态:草稿10/待初审20/待复审30/待缴费40/待制单50/待出单60/已出单70/已过期100(翻译)")
	private String statusN;
    @ApiModelProperty(value = "流程审核状态:正常/回退等")
	private String processStatus;
    @ApiModelProperty(value = "创建人")
	private String createBy;

	@DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
	@JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss",timezone ="GMT+8")
    @ApiModelProperty(value = "创建时间")
	private Date createTime;
    @ApiModelProperty(value = "更新人")
	private String updateBy;

	@DateTimeFormat(pattern="yyyy-MM-dd")
	@JsonFormat(pattern = "yyyy-MM-dd",timezone ="GMT+8")
    @ApiModelProperty(value = "更新时间")
	private Date updateTime;
    @ApiModelProperty(value = "是否删除")
	private Boolean delFlag;
	@ApiModelProperty(value = "待合并的每月投保单")
	private String combinePolicyId;

	@ApiModelProperty(value = "最新的每月投保单，不写入数据库，作查询使用")
	private InsurancePolicy insurancePolicy;

	@ApiModelProperty(value = "投保单号")
	private String policyNo;

	@DateTimeFormat(pattern="yyyy-MM-dd HH:mm:ss")
	@JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss",timezone ="GMT+8")
	@ApiModelProperty(value = "出单时间")
	private Date finishTime;


	/**
	 * 状态翻译
	 * @return
	 */
	public String getStatusN() {
		String statusN = "";

		if(StringUtils.isNotEmpty(status)) {
			try {
				PolicyStatus policyStatus = PolicyStatus.valueOf(Integer.valueOf(status));

				if (policyStatus != null) {
					statusN = policyStatus.getText();
				}
			}catch (Exception ex){
				System.out.println(ex.getMessage());
			}
		}

		return statusN;
	}
}