package com.jpsoft.picc.modules.common.utils;

import com.itextpdf.text.*;
import com.itextpdf.text.pdf.*;
import com.itextpdf.text.pdf.parser.ImageRenderInfo;
import com.itextpdf.text.pdf.parser.PdfReaderContentParser;
import com.itextpdf.text.pdf.parser.RenderListener;
import com.itextpdf.text.pdf.parser.TextRenderInfo;
import lombok.extern.slf4j.Slf4j;

import java.io.FileOutputStream;
import java.util.ArrayList;

/**
 * @author 墨鱼_mo
 * @date 2020-2-5 13:30
 * 水印
 */
@Slf4j
public class Watermark extends PdfPageEventHelper {
    Font FONT = new Font(Font.FontFamily.HELVETICA, 30, Font.BOLD, new GrayColor(0.95f));
    private String waterCont;//水印内容

    public Watermark() {
    }

    public Watermark(String waterCont) {
        this.waterCont = waterCont;
    }

    @Override
    public void onEndPage(PdfWriter writer, Document document) {
        for (int i = 0; i < 5; i++) {
            for (int j = 0; j < 5; j++) {
                ColumnText.showTextAligned(writer.getDirectContent(), Element.ALIGN_CENTER,
                        new Phrase(this.waterCont == null ? "PICC" : this.waterCont, FONT),
                        (50.5f + i * 250),
                        (40.0f + j * 150),
                        writer.getPageNumber() % 2 == 1 ? 45 : -45);
            }
        }
    }

    public static void imageWatermark(String inputPath, String outputPath,String imageUrl) throws Exception{

        try{
            PdfReader reader = new PdfReader(inputPath);
            PdfStamper stamper = new PdfStamper(reader, new FileOutputStream(outputPath));
            PdfGState gs1 = new PdfGState();
            gs1.setFillOpacity(0.8f);

            Image image = Image.getInstance(imageUrl);

            //设置白色背景图透明
            //如果是RGBImage,Image.Transparency数组的格式为{red起始值, red终止值, green起始值, green终止值, blue起始值, blue终止值};范围为0~255
            //image.setTransparency(new int[] { 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF});

            int n = reader.getNumberOfPages();
            PdfContentByte under;

            int pageNumber = 2;
            under = stamper.getOverContent(pageNumber);
            under.setGState(gs1);

            Rectangle pageRect = reader.getPageSizeWithRotation(pageNumber);

            image.scaleToFit(pageRect.getWidth()/6,pageRect.getHeight()/6);

            //读取【投保人签名 / 签章】位置
            PdfReaderContentParser pdfReaderContentParser = new PdfReaderContentParser(reader);

            String keyword = "投保人签名 / 签章";

            final ArrayList<Float> posList = new ArrayList<>();

            pdfReaderContentParser.processContent(pageNumber, new RenderListener() {
                @Override
                public void renderText(TextRenderInfo textRenderInfo) {
                    String text = textRenderInfo.getText(); // 整页内容

                    if (null != text && text.contains(keyword)) {
                        com.itextpdf.awt.geom.Rectangle2D.Float boundingRectangle = textRenderInfo.getBaseline().getBoundingRectange();
                        posList.add(boundingRectangle.x);
                        posList.add(boundingRectangle.y);
                    }
                }

                @Override
                public void renderImage(ImageRenderInfo arg0) {
                    // TODO Auto-generated method stub

                }

                @Override
                public void endTextBlock() {
                    // TODO Auto-generated method stub

                }

                @Override
                public void beginTextBlock() {
                    // TODO Auto-generated method stub

                }
            });

            if (posList.size()>0) {
                image.setAbsolutePosition(posList.get(0) + 100, posList.get(1));
                under.addImage(image);
            }

            for (int i = 3; i <= n; i++) {
                // 获得PDF最顶层
                under = stamper.getOverContent(i);
                under.setGState(gs1);

           //     Rectangle pageRect1 = reader.getPageSizeWithRotation(i);

                //A4像素 842*596
                float maxSize = 842;
             //   image.setRotation(45);
                image.scaleToFit(pageRect.getWidth()/6,pageRect.getHeight()/6);
                image.setAbsolutePosition(2*pageRect.getWidth()/3,4*pageRect.getHeight()/5);
                under.addImage(image);

//                for (int y = 0; y < Math.min(pageRect.getHeight(), maxSize); y += imgHeight)
//                {
//                    for (int x = 0; x < Math.min(pageRect.getWidth(), maxSize); x += imgWidth)
//                    {
//                        // 水印文字成45度角倾斜
////                        image.setRotation(30);// 旋转 弧度
//                        // 设置旋转角度
////                        image.setRotationDegrees(-45);// 旋转 角度
//                        // 设置等比缩放
////                        under.setColorFill(BaseColor.GRAY);
////                        image.scaleToFit(80,120);
//                        image.setRotation(45);
//                        image.setAbsolutePosition(x, y);
//                        under.addImage(image);
//                    }
//                }
            }
            stamper.close();
            reader.close();
        }catch (Exception e){
            log.error(e.getMessage(),e);
        }
    }


    public static void main(String[] args) {
        try {
            Watermark.imageWatermark("E:\\test.pdf","E:\\test2.pdf","C:\\picc\\logo.png");
        } catch (Exception e) {
            e.printStackTrace();
        }
        System.out.println("done");

    }
}



