package com.jpsoft.picc.modules.auth.controller;

import com.jpsoft.picc.modules.base.entity.Company;
import com.jpsoft.picc.modules.base.entity.CompanyUser;
import com.jpsoft.picc.modules.base.service.CompanyService;
import com.jpsoft.picc.modules.base.service.CompanyUserService;
import com.jpsoft.picc.modules.common.dto.MessageResult;
import com.jpsoft.picc.modules.common.utils.DES3;
import com.jpsoft.picc.modules.common.utils.PojoUtils;
import com.jpsoft.picc.modules.pub.dto.CompanyInfoDTO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.jasig.cas.client.authentication.AttributePrincipal;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.Date;
import java.util.UUID;

@Slf4j
@CrossOrigin
@Api(description="企业信息管理")
@RestController
@RequestMapping("/auth/company")
public class CompanyController {
    @Autowired
    private CompanyService companyService;

    @Autowired
    private CompanyUserService companyUserService;

    @GetMapping(value="detail")
    @ApiOperation(value = "获取企业信息")
    public MessageResult<CompanyInfoDTO> detail(HttpServletRequest request){
        MessageResult<CompanyInfoDTO> messageResult = new MessageResult<>();

        try {
            CompanyInfoDTO companyInfoDTO = new CompanyInfoDTO();

            //todo
            AttributePrincipal principal = (AttributePrincipal) request.getUserPrincipal();
            CompanyUser companyUser = companyUserService.findByUserName(principal.getName());
            Company company = null;

            if (companyUser!=null && StringUtils.isNotEmpty(companyUser.getCompanyId())) {
                company = companyService.get(companyUser.getCompanyId());
            }

            if(company!=null) {
                PojoUtils.map(company, companyInfoDTO);

                if(StringUtils.isNotEmpty(company.getPromoter())){
                    companyInfoDTO.setPromoterEnabled(false);
                }
                else{
                    companyInfoDTO.setPromoterEnabled(true);
                }

                messageResult.setData(companyInfoDTO);
            }
            else{
                companyInfoDTO.setPromoterEnabled(true);
                messageResult.setData(companyInfoDTO);
            }

            messageResult.setResult(true);
        }
        catch (Exception ex){
            messageResult.setResult(false);
            messageResult.setMessage(ex.getMessage());
        }

        return messageResult;
    }

    @PostMapping(value="save")
    @ApiOperation(value = "保存企业信息")
    public MessageResult<String> save(CompanyInfoDTO companyInfoDTO,HttpServletRequest request){
        MessageResult<String> messageResult = new MessageResult<>();

        try {
            //todo
            AttributePrincipal principal = (AttributePrincipal) request.getUserPrincipal();
            CompanyUser companyUser = companyUserService.findByUserName(principal.getName());

            if(companyUser==null){
                //可能直接通过cas统一登录页面登录，所以没有记录用户信息
                companyUser = new CompanyUser();
                companyUser.setId(UUID.randomUUID().toString());
                companyUser.setUserName(principal.getName());
                DES3 des3 = new DES3();
                companyUser.setPassword(des3.encrypt(DES3.DEFAULT_KEY, "123456"));
                companyUser.setDelFlag(false);
                companyUser.setCreateTime(new Date());

                companyUserService.insert(companyUser);
            }

            Company company = null;

//            if (!StringUtils.isEmpty(companyInfoDTO.getId())){
//                company = companyService.get(companyInfoDTO.getId());
//            }

            if(company==null && StringUtils.isNotEmpty(companyUser.getCompanyId())){
                company = companyService.get(companyUser.getCompanyId());
            }

            //身份证、营业执照、企业公章(附件)如果没上传时，会传null值
            if ("null".equals(companyInfoDTO.getLegalCardFile())){
                companyInfoDTO.setLegalCardFile("");
            }

            if ("null".equals(companyInfoDTO.getUsccFiles())){
                companyInfoDTO.setUsccFiles("");
            }

            if ("null".equals(companyInfoDTO.getCompanyStampFile())){
                companyInfoDTO.setCompanyStampFile("");
            }

            // 如果不设为null，更新时会将当前的company.id设为null
            // 从而企业用户的CompanyId会被设置为字符串"null"
            if ("null".equals(companyInfoDTO.getId())){
                companyInfoDTO.setId(null);
            }

            else if(StringUtils.isNotEmpty(companyInfoDTO.getId())){
                boolean existed = companyService.exist(companyInfoDTO.getId());

                if (!existed){
                    companyInfoDTO.setId(null);
                }
            }

            if (company==null) {
                company = new Company();
                PojoUtils.map(companyInfoDTO, company);

                company.setId(UUID.randomUUID().toString());
                company.setCreateTime(new Date());
                company.setCreateBy(principal.getName());
                company.setDelFlag(false);

                companyService.insert(company);

                messageResult.setData(company.getId());
            }
            else {
                PojoUtils.map(companyInfoDTO, company);
                company.setUpdateTime(new Date());
                company.setUpdateBy(principal.getName());

                companyService.update(company);

                messageResult.setData(company.getId());
            }

            companyUser.setCompanyId(company.getId());
            companyUser.setUpdateTime(new Date());
            companyUserService.update(companyUser);

            messageResult.setResult(true);
        }
        catch (Exception ex){
            log.error(ex.getMessage(),ex);

            messageResult.setResult(false);
            messageResult.setMessage(ex.getMessage());
        }

        return messageResult;
    }
}
